Struct BlerxtxIscr
#[repr(transparent)]pub struct BlerxtxIscr(pub u8);Expand description
BLERXTX_ISCR register.
Tuple Fields
0: u8Implementations
impl BlerxtxIscr
impl BlerxtxIscr
pub const fn tx_isc(&self) -> bool
pub const fn tx_isc(&self) -> bool
TX_ISC:interrupt status on TX_SEQUENCE signal (can be a rising or a falling edge depending on BLERXTX_IEVR and BLERXTX_IBER): 0: no activity on TX_SEQUENCE detected. 1: activity on TX_SEQUENCE occurred.
pub fn set_tx_isc(&mut self, val: bool)
pub fn set_tx_isc(&mut self, val: bool)
TX_ISC:interrupt status on TX_SEQUENCE signal (can be a rising or a falling edge depending on BLERXTX_IEVR and BLERXTX_IBER): 0: no activity on TX_SEQUENCE detected. 1: activity on TX_SEQUENCE occurred.
pub const fn rx_isc(&self) -> bool
pub const fn rx_isc(&self) -> bool
RX_ISC: interrupt status on RX_SEQUENCE signal (can be a rising or a falling edge depending on BLERXTX_IEVR and BLERXTX_IBER): 0: no activity on RX_SEQUENCE detected. 1: activity on RX_SEQUENCE occurred.
pub fn set_rx_isc(&mut self, val: bool)
pub fn set_rx_isc(&mut self, val: bool)
RX_ISC: interrupt status on RX_SEQUENCE signal (can be a rising or a falling edge depending on BLERXTX_IEVR and BLERXTX_IBER): 0: no activity on RX_SEQUENCE detected. 1: activity on RX_SEQUENCE occurred.
pub const fn tx_isedge(&self) -> bool
pub const fn tx_isedge(&self) -> bool
TX_ISEDGE: interrupt edge status on TX_SEQUENCE signal: 0: falling edge on TX_SEQUENCE detected. 1: rising edge on TX_SEQUENCE detected.
pub fn set_tx_isedge(&mut self, val: bool)
pub fn set_tx_isedge(&mut self, val: bool)
TX_ISEDGE: interrupt edge status on TX_SEQUENCE signal: 0: falling edge on TX_SEQUENCE detected. 1: rising edge on TX_SEQUENCE detected.
pub const fn rx_isedge(&self) -> bool
pub const fn rx_isedge(&self) -> bool
RX_ISEDGE: interrupt edge status on RX_SEQUENCE signal: 0: falling edge on RX_SEQUENCE detected. 1: rising edge on RX_SEQUENCE detected.
pub fn set_rx_isedge(&mut self, val: bool)
pub fn set_rx_isedge(&mut self, val: bool)
RX_ISEDGE: interrupt edge status on RX_SEQUENCE signal: 0: falling edge on RX_SEQUENCE detected. 1: rising edge on RX_SEQUENCE detected.