stm32-metapac

Crates

git

Versions

stm32wb06cc

Flavors

PwrcIscr

Struct PwrcIscr 

#[repr(transparent)]
pub struct PwrcIscr(pub u32);
PWRC_ISCR register.

Tuple Fields

0: u32

Implementations



impl PwrcIscr

pub const fn borh_isc(&self) -> bool

BORH_ISC: BORH interrupt status. 0: no pending interrupt. 1: voltage went under BORH threshold / interrupt occurred (if enabled). Cleared by writing 1 in the bit.

pub fn set_borh_isc(&mut self, val: bool)

BORH_ISC: BORH interrupt status. 0: no pending interrupt. 1: voltage went under BORH threshold / interrupt occurred (if enabled). Cleared by writing 1 in the bit.

pub const fn pvd_isc(&self) -> bool

PVD_ISC: Programmable Voltage Detector status. 0: no pending interrupt. 1: voltage went under programmed threshold / interrupt occurred (if enabled). Cleared by writing 1 in the bit.

pub fn set_pvd_isc(&mut self, val: bool)

PVD_ISC: Programmable Voltage Detector status. 0: no pending interrupt. 1: voltage went under programmed threshold / interrupt occurred (if enabled). Cleared by writing 1 in the bit.

pub const fn wkup_isc(&self) -> bool

WKUP_ISC: Indicates the Power Controller receives a Wakeup event. 0: no pending interrupt. 1: Wakeup event on PWRC occurred / interrupt occurred (if enabled). Cleared by writing 1 in the bit. This flag will be read at 1 if a wakeup event arrives so close to the low power mode entry requests that the PWRC aborts before shutting down the system.

pub fn set_wkup_isc(&mut self, val: bool)

WKUP_ISC: Indicates the Power Controller receives a Wakeup event. 0: no pending interrupt. 1: Wakeup event on PWRC occurred / interrupt occurred (if enabled). Cleared by writing 1 in the bit. This flag will be read at 1 if a wakeup event arrives so close to the low power mode entry requests that the PWRC aborts before shutting down the system.